![pre-commit status](https://img.shields.io/github/actions/workflow/status/check-phat-nguoi/cpn-core/pre-commit.yml?style=for-the-badge&label=pre%20commit&branch=main&logo=precommit)
![codeql status](https://img.shields.io/github/actions/workflow/status/check-phat-nguoi/cpn-core/codeql.yml?style=for-the-badge&label=codeql&branch=main)
![GitHub License](https://img.shields.io/github/license/check-phat-nguoi/cpn-core?style=for-the-badge)
